CrystalMedia Exportify Helper

# CrystalMedia → Exportify Playlist CSV Guide

Playlist (must match): (loading...)

Save CSV to: `./csv`

1. Click Open Exportify and log in to Spotify.
2. In Exportify, export the playlist shown above.
3. Save the CSV file into the exact folder shown above.
4. Keep the filename containing the playlist name to allow automatic matching.
5. Return to CrystalMedia and press Enter on CSV prompt to auto-detect.

Open Exportify Open Playlist Link